searchData={"content_type":"text/markdown","items":[{"doc":"This module contains the notify macro and context function you can use in\nyour applications.","ref":"Honeybadger.html","title":"Honeybadger","type":"module"},{"doc":"By default the `HONEYBADGER_API_KEY` environment variable is used to find\nyour API key for Honeybadger. You can also manually set your API key by\nconfiguring the `:honeybadger` application. You can see the default\nconfiguration in the `default_config/0` private function at the bottom of\nthis file.\n\n    config :honeybadger,\n      api_key: \"mysupersecretkey\",\n      environment_name: :prod,\n      app: :my_app_name,\n      exclude_envs: [:dev, :test],\n      breadcrumbs_enabled: true,\n      ecto_repos: [MyAppName.Ecto.Repo],\n      hostname: \"myserver.domain.com\",\n      origin: \"https://api.honeybadger.io\",\n      sasl_logging_only: false,\n      proxy: \"http://proxy.net:PORT\",\n      proxy_auth: {\"Username\", \"Password\"},\n      project_root: \"/home/skynet\",\n      revision: System.get_env(\"GIT_REVISION\"),\n      use_logger: true,\n      notice_filter: Honeybadger.NoticeFilter.Default,\n      filter: Honeybadger.Filter.Default,\n      filter_keys: [:password, :credit_card],\n      exclude_errors: []","ref":"Honeybadger.html#module-configuring","title":"Configuring - Honeybadger","type":"module"},{"doc":"If you use `Honeybadger.Plug` and `Honeybadger.Logger` included in this\nlibrary you won't need to use `Honeybadger.notify/2` for manual reporting\nvery often. However, if you need to send custom notifications you can do so:\n\n    try do\n      raise RunTimeError, message: \"Oops\"\n    rescue\n      exception ->\n        context = %{user_id: 1, account: \"A Very Important Customer\"}\n\n        Honeybadger.notify(\n          exception,\n          metadata: context,\n          stacktrace: __STACKTRACE__,\n          fingerprint: \"user-1\"\n        )\n    end\n\nNote that `notify` may be used outside of `try`, but it will use a different\nmechanism for getting the current stacktrace. The resulting stacktrace may be\nnoisier and less accurate.","ref":"Honeybadger.html#module-notifying","title":"Notifying - Honeybadger","type":"module"},{"doc":"You can add an arbitrary map of context that will get sent to the Honeybadger\nAPI when/if an exception occurs in that process. Do keep in mind the process\ndictionary is used for retrieving this context so try not to put large data\nstructures in the context.\n\n    Honeybadger.context(user_id: 1, account: \"My Favorite Customer\")\n    Honeybadger.context(%{user_id: 2, account: \"That Needy Customer\"})","ref":"Honeybadger.html#module-setting-context","title":"Setting Context - Honeybadger","type":"module"},{"doc":"If you're using Phoenix, or any Plug-based Elixir web framework, you can\n`use` the `Honeybadger.Plug` module in your Router and all exceptions in web\nrequests will automatically be reported to Honeybadger.\n\n    defmodule MoneyPrinter.Router do\n      use MoneyPrinter.Web, :router\n      use Honeybadger.Plug\n    end\n\nYou can also automatically set useful context on every request by defining\na Plug compatible function:\n\n    defmodule MoneyPrinter.Router do\n      use MoneyPrinter.Web, :router\n      use Honeybadger.Plug\n\n      plug :set_honeybadger_context\n\n      # your routes\n\n      defp set_honeybadger_context(conn, _opts) do\n        user = get_user(conn)\n        Honeybadger.context(user_id: user.id, account: user.account)\n        conn\n      end\n    end","ref":"Honeybadger.html#module-using-the-plug","title":"Using the Plug - Honeybadger","type":"module"},{"doc":"By default the logger is enabled. The logger will automatically receive any\nerror reports for SASL compliant processes such as `GenServers`, `GenEvents`,\n`Agents`, `Tasks` and any process spawned using `proc_lib`. You can disable the\nlogger by setting `use_logger` to false in your Honeybadger config.","ref":"Honeybadger.html#module-using-the-error-logger","title":"Using the Error Logger - Honeybadger","type":"module"},{"doc":"Before data is sent to Honeybadger, it is run through a filter which can\nremove sensitive fields or do other processing on the data. For basic\nfiltering the default configuration is equivalent to:\n\n    config :honeybadger,\n      filter: Honeybadger.Filter.Default,\n      filter_keys: [:password, :credit_card]\n\nThis will remove any entries in the context, session, cgi_data and\nparams that match one of the filter keys. The check is case insensitive\nand matches atoms or strings.\n\nIf the `Filter.Default` does not suit your needs, you can implement your\nown filter. A simple filter looks like:\n\n    defmodule MyApp.MyFilter do\n      use Honeybadger.Filter.Mixin\n\n      # drop password fields out of the context Map\n      def filter_context(context), do: Map.drop(context, [:password])\n\n      # remove secrets from an error message\n      def filter_error_message(message),\n        do: Regex.replace(~r/Secret: w+/, message, \"Secret: ***\")\n    end\n\nSee `Honeybadger.Filter` for details on implementing your own filter.","ref":"Honeybadger.html#module-using-a-notification-filter","title":"Using a Notification Filter - Honeybadger","type":"module"},{"doc":"Breadcrumbs allow you to record events along a processes execution path. If\nan error is thrown, the set of breadcrumb events will be sent along with the\nnotice. These breadcrumbs can contain useful hints while debugging.\n\nBreadcrumbs are stored in the logger context, referenced by the calling\nprocess. If you are sending messages between processes, breadcrumbs will not\ntransfer automatically. Since a typical system might have many processes, it\nis advised that you be conservative when storing breadcrumbs as each\nbreadcrumb consumes memory.\n\nSee `Honeybadger.add_breadcrumb` for info on how to add custom breadcrumbs.","ref":"Honeybadger.html#module-breadcrumbs","title":"Breadcrumbs - Honeybadger","type":"module"},{"doc":"We leverage the `telemetry` library to automatically create breadcrumbs from\nspecific events.\n\n#### Phoenix\n\nIf you are using `phoenix` (>= v1.4.7) we add a breadcrumb from the router\nstart event.\n\n#### Ecto\n\nWe can create breadcrumbs from Ecto SQL calls if you are using `ecto_sql` (>=\nv3.1.0). You also must specify in the config which ecto adapters you want to\nbe instrumented:\n\n    config :honeybadger,\n      ecto_repos: [MyApp.Repo]\n\n#### Insights","ref":"Honeybadger.html#module-automatic-breadcrumbs","title":"Automatic Breadcrumbs - Honeybadger","type":"module"},{"doc":"Stores a breadcrumb item.\n\nAppends a breadcrumb to the notice. Use this when you want to add some custom\ndata to your breadcrumb trace in effort to help debugging. If a notice is\nreported to Honeybadger, all breadcrumbs within the execution path will be\nappended to the notice. You will be able to view the breadcrumb trace in the\nHoneybadger interface to see what events led up to the notice.","ref":"Honeybadger.html#add_breadcrumb/2","title":"Honeybadger.add_breadcrumb/2","type":"function"},{"doc":"Honeybadger.add_breadcrumb(\"email sent\", metadata: %{\n      user: user.id, message: message\n    })\n    => :ok","ref":"Honeybadger.html#add_breadcrumb/2-breadcrumb-with-metadata","title":"Breadcrumb with metadata - Honeybadger.add_breadcrumb/2","type":"function"},{"doc":"Honeybadger.add_breadcrumb(\"ETS Lookup\", category: \"query\", metadata: %{\n      key: key,\n      value: value\n    })\n    => :ok","ref":"Honeybadger.html#add_breadcrumb/2-breadcrumb-with-specified-category-this-will-display-a-query-icon-in-the-interface","title":"Breadcrumb with specified category. This will display a query icon in the interface - Honeybadger.add_breadcrumb/2","type":"function"},{"doc":"Clears the context.\n\nNote that because context is stored as logger metadata, clearing the context will clear _all_\nmetadata.","ref":"Honeybadger.html#clear_context/0","title":"Honeybadger.clear_context/0","type":"function"},{"doc":"Clears the current event context.","ref":"Honeybadger.html#clear_event_context/0","title":"Honeybadger.clear_event_context/0","type":"function"},{"doc":"Retrieves the context that will be sent to the Honeybadger API when an exception occurs in the\ncurrent process.\n\nContext is stored as Logger metadata, and is in fact an alias for `Logger.metadata/0`.","ref":"Honeybadger.html#context/0","title":"Honeybadger.context/0","type":"function"},{"doc":"Store additional context in the process metadata.\n\nThis function will merge the given map or keyword list into the existing metadata, with the\nexception of setting a key to `nil`, which will remove that key from the metadata.\n\nContext is stored as Logger metadata.","ref":"Honeybadger.html#context/1","title":"Honeybadger.context/1","type":"function"},{"doc":"","ref":"Honeybadger.html#event/1","title":"Honeybadger.event/1","type":"function"},{"doc":"","ref":"Honeybadger.html#event/2","title":"Honeybadger.event/2","type":"function"},{"doc":"Retrieves the current event context.","ref":"Honeybadger.html#event_context/0","title":"Honeybadger.event_context/0","type":"function"},{"doc":"Merges the given map or keyword list into the current event context.","ref":"Honeybadger.html#event_context/1","title":"Honeybadger.event_context/1","type":"function"},{"doc":"Fetch all configuration specific to the :honeybadger application.\n\nThis resolves values the same way that `get_env/1` does, so it resolves\n:system tuple variables correctly.","ref":"Honeybadger.html#get_all_env/0","title":"Honeybadger.get_all_env/0","type":"function"},{"doc":"Honeybadger.get_all_env()\n    #=> [api_key: \"12345\", environment_name: \"dev\", ...]","ref":"Honeybadger.html#get_all_env/0-example","title":"Example - Honeybadger.get_all_env/0","type":"function"},{"doc":"Fetch configuration specific to the :honeybadger application.","ref":"Honeybadger.html#get_env/1","title":"Honeybadger.get_env/1","type":"function"},{"doc":"Honeybadger.get_env(:exclude_envs)\n    #=> [:dev, :test]","ref":"Honeybadger.html#get_env/1-example","title":"Example - Honeybadger.get_env/1","type":"function"},{"doc":"Inherits the current event context from a parent process.","ref":"Honeybadger.html#inherit_event_context/0","title":"Honeybadger.inherit_event_context/0","type":"function"},{"doc":"Send an exception notification, if reporting is enabled.\n\nThis is the primary way to do manual error reporting and it is also used\ninternally to deliver logged errors.","ref":"Honeybadger.html#notify/1","title":"Honeybadger.notify/1","type":"function"},{"doc":"Accessing the stacktrace outside of a rescue/catch is deprecated. Notifications should happen\ninside of a rescue/catch block so that the stacktrace can be provided with `__STACKTRACE__`.\nStacktraces _must_ be provided and won't be automatically extracted from the current process.","ref":"Honeybadger.html#notify/1-stacktrace","title":"Stacktrace - Honeybadger.notify/1","type":"function"},{"doc":"try do\n      do_something_risky()\n    rescue\n      exception ->\n        Honeybadger.notify(exception, metadata: %{}, stacktrace: __STACKTRACE__)\n    end\n\nSend a notification directly from a string, which will be sent as a\n`RuntimeError`:\n\n    iex> Honeybadger.notify(\"custom error message\")\n    :ok\n\nSend a notification as a `class` and `message`:\n\n    iex> Honeybadger.notify(%{class: \"SpecialError\", message: \"custom message\"})\n    :ok\n\nSend a notification as a `badarg` atom:\n\n    iex> Honeybadger.notify(:badarg)\n    :ok\n\nIf desired additional metadata can be provided as well:\n\n    iex> Honeybadger.notify(%RuntimeError{}, metadata: %{culprit_id: 123})\n    :ok\n\nIf desired fingerprint can be provided as well:\n\n    iex> Honeybadger.notify(%RuntimeError{}, fingerprint: \"culprit_id-123\")\n    :ok","ref":"Honeybadger.html#notify/1-example","title":"Example - Honeybadger.notify/1","type":"function"},{"doc":"","ref":"Honeybadger.html#notify/2","title":"Honeybadger.notify/2","type":"function"},{"doc":"","ref":"Honeybadger.html#notify/3","title":"Honeybadger.notify/3","type":"function"},{"doc":"","ref":"Honeybadger.html#t:notify_options/0","title":"Honeybadger.notify_options/0","type":"type"},{"doc":"Specification for filtering instrumented events.\n\nMost users won't need this, but if you need complete control over\nfiltering, implement this behaviour and configure like:\n\n    config :honeybadger,\n      event_filter: MyApp.MyEventFilter","ref":"Honeybadger.EventFilter.html","title":"Honeybadger.EventFilter","type":"behaviour"},{"doc":"Filters all Insights events.","ref":"Honeybadger.EventFilter.html#c:filter_event/1","title":"Honeybadger.EventFilter.filter_event/1","type":"callback"},{"doc":"* `event` - The current event map","ref":"Honeybadger.EventFilter.html#c:filter_event/1-parameters","title":"Parameters - Honeybadger.EventFilter.filter_event/1","type":"callback"},{"doc":"The filtered metadata map that will be sent to Honeybadger or `nil` to skip\n  the event.","ref":"Honeybadger.EventFilter.html#c:filter_event/1-returns","title":"Returns - Honeybadger.EventFilter.filter_event/1","type":"callback"},{"doc":"Filters an instrumented telemetry event.","ref":"Honeybadger.EventFilter.html#c:filter_telemetry_event/3","title":"Honeybadger.EventFilter.filter_telemetry_event/3","type":"callback"},{"doc":"* `data` - The current data for the event\n  * `raw_event` - The raw event metadata\n  * `event` - The telemetry event being processed, e.g. [:phoenix, :endpoint, :start]","ref":"Honeybadger.EventFilter.html#c:filter_telemetry_event/3-parameters","title":"Parameters - Honeybadger.EventFilter.filter_telemetry_event/3","type":"callback"},{"doc":"The filtered metadata map that will be sent to Honeybadger or `nil` to skip\n  the event.","ref":"Honeybadger.EventFilter.html#c:filter_telemetry_event/3-returns","title":"Returns - Honeybadger.EventFilter.filter_telemetry_event/3","type":"callback"},{"doc":"","ref":"Honeybadger.EventFilter.Default.html","title":"Honeybadger.EventFilter.Default","type":"module"},{"doc":"","ref":"Honeybadger.EventFilter.Default.html#apply_default_telemetry_filtering/1","title":"Honeybadger.EventFilter.Default.apply_default_telemetry_filtering/1","type":"function"},{"doc":"","ref":"Honeybadger.EventFilter.Default.html#filter_event/1","title":"Honeybadger.EventFilter.Default.filter_event/1","type":"function"},{"doc":"","ref":"Honeybadger.EventFilter.Default.html#filter_telemetry_event/3","title":"Honeybadger.EventFilter.Default.filter_telemetry_event/3","type":"function"},{"doc":"Provides a mixin for implementing the Honeybadger.EventFilter behaviour.\n\nIf you need to implement custom filtering for events, you can define your own filter module\nand register it in the config. For example, to filter based on event_type:\n\n    defmodule MyApp.MyFilter do\n      use Honeybadger.EventFilter.Mixin\n\n      # Drop analytics events by returning nil\n      def filter_event(%{event_type: \"analytics\"} = _event), do: nil\n\n      # Anonymize user data in login events\n      def filter_event(%{event_type: \"login\"} = event) do\n        event\n        |> update_in([:data, :user_email], fn _ -> \"[REDACTED]\" end)\n        |> put_in([:metadata, :filtered], true)\n      end\n\n      # For telemetry events, you can customize while still applying default filtering\n      def filter_telemetry_event(data, raw, event) do\n        # First apply default filtering\n        filtered_data = apply_default_telemetry_filtering(data)\n\n        # Then apply custom logic\n        case event do\n          [:auth, :login, :start] ->\n            Map.put(filtered_data, :security_filtered, true)\n          _ ->\n            filtered_data\n        end\n      end\n\n      # Keep all other events as they are\n      def filter_event(event), do: event\n    end\n\nAnd set the configuration to:\n\n    config :honeybadger,\n      event_filter: MyApp.MyFilter\n\nReturn `nil` from `filter_event/1` to prevent the event from being processed.\nIf you override `filter_telemetry_event/3`, you can still apply the default\nfiltering by calling `apply_default_telemetry_filtering/1`.","ref":"Honeybadger.EventFilter.Mixin.html","title":"Honeybadger.EventFilter.Mixin","type":"module"},{"doc":"A GenServer that batches and sends events with retry and throttling logic.\n\nIt accumulates events in a queue, forms batches when the batch size is reached or\nwhen a flush timeout expires, and then sends these batches to a backend module.\nIf a batch fails to send, it will be retried (up to a configurable maximum) or dropped.\nIn case of throttling (e.g. receiving a 429), the flush delay is increased.","ref":"Honeybadger.EventsWorker.html","title":"Honeybadger.EventsWorker","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Honeybadger.EventsWorker.html#child_spec/1","title":"Honeybadger.EventsWorker.child_spec/1","type":"function"},{"doc":"","ref":"Honeybadger.EventsWorker.html#push/2","title":"Honeybadger.EventsWorker.push/2","type":"function"},{"doc":"","ref":"Honeybadger.EventsWorker.html#start_link/1","title":"Honeybadger.EventsWorker.start_link/1","type":"function"},{"doc":"","ref":"Honeybadger.EventsWorker.html#state/1","title":"Honeybadger.EventsWorker.state/1","type":"function"},{"doc":"","ref":"Honeybadger.EventsWorker.State.html","title":"Honeybadger.EventsWorker.State","type":"module"},{"doc":"Function that accepts a list of events to be processed.","ref":"Honeybadger.EventsWorker.State.html#t:send_events_fn/0","title":"Honeybadger.EventsWorker.State.send_events_fn/0","type":"type"},{"doc":"State for the event batching GenServer.","ref":"Honeybadger.EventsWorker.State.html#t:t/0","title":"Honeybadger.EventsWorker.State.t/0","type":"type"},{"doc":"Specification of user overrideable exclude_errors function.","ref":"Honeybadger.ExcludeErrors.html","title":"Honeybadger.ExcludeErrors","type":"behaviour"},{"doc":"Takes in a notice struct and supposed to return true or false depending with the user Specification","ref":"Honeybadger.ExcludeErrors.html#c:exclude_error?/1","title":"Honeybadger.ExcludeErrors.exclude_error?/1","type":"callback"},{"doc":"The default implementation for the `exclude_errors` configuration. Doesn't\nexclude any error.","ref":"Honeybadger.ExcludeErrors.Default.html","title":"Honeybadger.ExcludeErrors.Default","type":"module"},{"doc":"Specification of user overrideable filter functions.\n\nSee moduledoc for `Honeybadger.Filter.Mixin` for details on implementing\nyour own filter.","ref":"Honeybadger.Filter.html","title":"Honeybadger.Filter","type":"behaviour"},{"doc":"Filter breadcrumbs. This filter function receives a list of Breadcrumb\nstructs. You could use any Enum function to constrain the set. Let's say you\nwant to remove any breadcrumb that have metadata that contain SSN:\n\ndef filter_breadcrumbs(breadcrumbs) do\n  Enum.reject(breadcrumbs, fn breadcrumb -> do\n    Map.has_key?(breadcrumb.metadata, :ssn)\n  end)\nend","ref":"Honeybadger.Filter.html#c:filter_breadcrumbs/1","title":"Honeybadger.Filter.filter_breadcrumbs/1","type":"callback"},{"doc":"For applications that use `Honeybadger.Plug`, filter the cgi_data.\n\n`cgi_data` is a map of `String.t` to `String.t` which includes HTTP headers\nand other pre-defined request data (including `PATH_INFO`, `QUERY_STRING`,\n`SERVER_PORT` etc.).","ref":"Honeybadger.Filter.html#c:filter_cgi_data/1","title":"Honeybadger.Filter.filter_cgi_data/1","type":"callback"},{"doc":"Filter the context Map.  The context is a map of application supplied data.","ref":"Honeybadger.Filter.html#c:filter_context/1","title":"Honeybadger.Filter.filter_context/1","type":"callback"},{"doc":"Filter the error message string.  This is the message from the most\nrecently thrown error.","ref":"Honeybadger.Filter.html#c:filter_error_message/1","title":"Honeybadger.Filter.filter_error_message/1","type":"callback"},{"doc":"For applications that use `Honeybadger.Plug`, filters the query parameters.\nThe parameters is a map of `String.t` to `String.t`, e.g.:\n\n    %{\"user_name\" => \"fred\", \"password\" => \"12345\"}","ref":"Honeybadger.Filter.html#c:filter_params/1","title":"Honeybadger.Filter.filter_params/1","type":"callback"},{"doc":"For applications that use `Honeybadger.Plug`, filter the session.","ref":"Honeybadger.Filter.html#c:filter_session/1","title":"Honeybadger.Filter.filter_session/1","type":"callback"},{"doc":"The default implementation for the `filter` configuration.  Removes\nkeys listed in `filter_keys` from maps and respects the\n`filter_disable_*` configuration values.","ref":"Honeybadger.Filter.Default.html","title":"Honeybadger.Filter.Default","type":"module"},{"doc":"","ref":"Honeybadger.Filter.Default.html#filter_breadcrumbs/1","title":"Honeybadger.Filter.Default.filter_breadcrumbs/1","type":"function"},{"doc":"","ref":"Honeybadger.Filter.Default.html#filter_cgi_data/1","title":"Honeybadger.Filter.Default.filter_cgi_data/1","type":"function"},{"doc":"","ref":"Honeybadger.Filter.Default.html#filter_context/1","title":"Honeybadger.Filter.Default.filter_context/1","type":"function"},{"doc":"","ref":"Honeybadger.Filter.Default.html#filter_error_message/1","title":"Honeybadger.Filter.Default.filter_error_message/1","type":"function"},{"doc":"","ref":"Honeybadger.Filter.Default.html#filter_map/2","title":"Honeybadger.Filter.Default.filter_map/2","type":"function"},{"doc":"","ref":"Honeybadger.Filter.Default.html#filter_params/1","title":"Honeybadger.Filter.Default.filter_params/1","type":"function"},{"doc":"","ref":"Honeybadger.Filter.Default.html#filter_session/1","title":"Honeybadger.Filter.Default.filter_session/1","type":"function"},{"doc":"A default implementation of `Honeybadger.Filter`.\n\nIf you need to implement custom filtering for one or more of the elements in\na `Honeybadger.Notice`, you can define your own filter module and register it\nin the config.  E.g., if you wanted to filter the error message string, but\nkeep all of the other default filtering, you could do:\n\n    defmodule MyApp.MyFilter do\n      use Honeybadger.Filter.Mixin\n\n      def filter_error_message(message) do\n        # replace passwords in error message with `\"xxx\"`\n        Regex.replace(~r/(password: *)\"([^\"]+)\"/, message, ~s(\\1\"xxx\"))\n      end\n    end\n\nAnd set the configuration to:\n\n    config :honeybadger,\n      filter: MyApp.MyFilter\n\nSee the documentation for `Honeybadger.Filter` for a list of functions that\nmay be overridden.  The default implementations for all of the functions that\ntake a `map` are to remove any keys from the map that match a key in\n`filter_keys`. The check matches atoms and strings in a case insensitive\nmanner.","ref":"Honeybadger.Filter.Mixin.html","title":"Honeybadger.Filter.Mixin","type":"module"},{"doc":"The callbacks required to implement the FingerprintAdapter behaviour","ref":"Honeybadger.FingerprintAdapter.html","title":"Honeybadger.FingerprintAdapter","type":"behaviour"},{"doc":"This function receives a `t:Honeybadger.Notice.t/0` and must return a string that will be used\nas a fingerprint for the request:\n\n    def parse(notice) do\n      notice.notifier.language <> \"_\" <> notice.notifier.name\n    end","ref":"Honeybadger.FingerprintAdapter.html#c:parse/1","title":"Honeybadger.FingerprintAdapter.parse/1","type":"callback"},{"doc":"HTTP adapter helper module.\n\nYou can configure the HTTP adapter that Honeybadger uses by setting the\nfollowing option:\n\n    http_adapter: Honeybadger.HTTPAdapter.Req\n\nDefault options can be set by passing a list of options:\n\n    http_adapter: {Honeybadger.HTTPAdapter.Req, [...]}\n\nYou can also set the client for the application:\n\n    config :honeybadger, :http_adapter, Honeybadger.HTTPAdapter.Req","ref":"Honeybadger.HTTPAdapter.html","title":"Honeybadger.HTTPAdapter","type":"behaviour"},{"doc":"defmodule MyApp.MyHTTPAdapter do\n      @behaviour Honeybadger.HTTPAdapter\n\n      @impl true\n      def request(method, url, body, headers, opts) do\n        # ...\n      end\n\n      @impl true\n      def decode_response_body(response, opts) do\n        # ...\n      end\n    end","ref":"Honeybadger.HTTPAdapter.html#module-usage","title":"Usage - Honeybadger.HTTPAdapter","type":"behaviour"},{"doc":"","ref":"Honeybadger.HTTPAdapter.html#t:body/0","title":"Honeybadger.HTTPAdapter.body/0","type":"type"},{"doc":"","ref":"Honeybadger.HTTPAdapter.html#c:decode_response_body/2","title":"Honeybadger.HTTPAdapter.decode_response_body/2","type":"callback"},{"doc":"","ref":"Honeybadger.HTTPAdapter.html#t:headers/0","title":"Honeybadger.HTTPAdapter.headers/0","type":"type"},{"doc":"","ref":"Honeybadger.HTTPAdapter.html#t:method/0","title":"Honeybadger.HTTPAdapter.method/0","type":"type"},{"doc":"Makes an HTTP request.","ref":"Honeybadger.HTTPAdapter.html#request/5","title":"Honeybadger.HTTPAdapter.request/5","type":"function"},{"doc":"- `:http_adapter` - The HTTP adapter to use, defaults to to one of the available adapters\n  (Req is preferred, falling back to Hackney if available)","ref":"Honeybadger.HTTPAdapter.html#request/5-options","title":"Options - Honeybadger.HTTPAdapter.request/5","type":"function"},{"doc":"","ref":"Honeybadger.HTTPAdapter.html#c:request/5","title":"Honeybadger.HTTPAdapter.request/5","type":"callback"},{"doc":"Validates that the configured HTTP adapter's dependencies are available.\n\nThis should be called during application startup to ensure that the\nconfigured adapter can be used.","ref":"Honeybadger.HTTPAdapter.html#validate_adapter_availability!/0","title":"Honeybadger.HTTPAdapter.validate_adapter_availability!/0","type":"function"},{"doc":"Struct used by HTTP adapters to normalize HTTP responses.","ref":"Honeybadger.HTTPAdapter.HTTPResponse.html","title":"Honeybadger.HTTPAdapter.HTTPResponse","type":"module"},{"doc":"","ref":"Honeybadger.HTTPAdapter.HTTPResponse.html#format/1","title":"Honeybadger.HTTPAdapter.HTTPResponse.format/1","type":"function"},{"doc":"","ref":"Honeybadger.HTTPAdapter.HTTPResponse.html#t:header/0","title":"Honeybadger.HTTPAdapter.HTTPResponse.header/0","type":"type"},{"doc":"","ref":"Honeybadger.HTTPAdapter.HTTPResponse.html#t:t/0","title":"Honeybadger.HTTPAdapter.HTTPResponse.t/0","type":"type"},{"doc":"HTTP adapter module for making http requests with `:hackney`.\n\nYou can also override the hackney options by updating the configuration:\n\n    http_adapter: {Honeybadger.HTTPAdapter.Hackney, [...]}\n\nSee `Honeybadger.HTTPAdapter` for more.","ref":"Honeybadger.HTTPAdapter.Hackney.html","title":"Honeybadger.HTTPAdapter.Hackney","type":"module"},{"doc":"HTTP adapter module for making http requests with Req.\n\nYou can also override the Req options by updating the configuration:\n\n    http_adapter: {Honeybadger.HTTPAdapter.Req, [...]}\n\nSee `Honeybadger.HTTPAdapter` for more.","ref":"Honeybadger.HTTPAdapter.Req.html","title":"Honeybadger.HTTPAdapter.Req","type":"module"},{"doc":"Captures telemetry events from GraphQL operations executed via Absinthe.","ref":"Honeybadger.Insights.Absinthe.html","title":"Honeybadger.Insights.Absinthe","type":"module"},{"doc":"By default, this module listens for the following Absinthe telemetry events:\n\n    \"absinthe.execute.operation.stop\"\n    \"absinthe.execute.operation.exception\"","ref":"Honeybadger.Insights.Absinthe.html#module-default-configuration","title":"Default Configuration - Honeybadger.Insights.Absinthe","type":"module"},{"doc":"You can customize the telemetry events to listen for by updating the insights_config:\n\n    config :honeybadger, insights_config: %{\n      absinthe: %{\n        telemetry_events: [\n          [:absinthe, :execute, :operation, :stop],\n          [:absinthe, :execute, :operation, :exception],\n          [:absinthe, :resolve, :field, :stop]\n        ]\n      }\n    }\n\nNote that adding field-level events like \"absinthe.resolve.field.stop\" can\nsignificantly increase the number of telemetry events generated.","ref":"Honeybadger.Insights.Absinthe.html#module-custom-configuration","title":"Custom Configuration - Honeybadger.Insights.Absinthe","type":"module"},{"doc":"Attaches telemetry handlers if all required dependencies are available.","ref":"Honeybadger.Insights.Absinthe.html#attach/0","title":"Honeybadger.Insights.Absinthe.attach/0","type":"function"},{"doc":"Attaches a telemetry handler for a specific event.","ref":"Honeybadger.Insights.Absinthe.html#attach_event/1","title":"Honeybadger.Insights.Absinthe.attach_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Absinthe.html#dependencies_available?/0","title":"Honeybadger.Insights.Absinthe.dependencies_available?/0","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Absinthe.html#event_filter/3","title":"Honeybadger.Insights.Absinthe.event_filter/3","type":"function"},{"doc":"Extracts metadata from the telemetry event.\nChild modules should override this for specific events.","ref":"Honeybadger.Insights.Absinthe.html#extract_metadata/2","title":"Honeybadger.Insights.Absinthe.extract_metadata/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Absinthe.html#get_insights_config/2","title":"Honeybadger.Insights.Absinthe.get_insights_config/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Absinthe.html#get_telemetry_events/0","title":"Honeybadger.Insights.Absinthe.get_telemetry_events/0","type":"function"},{"doc":"Implementation of handle_telemetry that can be called by overriding methods.","ref":"Honeybadger.Insights.Absinthe.html#handle_event_impl/4","title":"Honeybadger.Insights.Absinthe.handle_event_impl/4","type":"function"},{"doc":"Handles telemetry events and processes the data.\nThis implementation forwards to handle_event_impl which can be overridden\nby child modules to customize behavior while still calling the parent implementation.","ref":"Honeybadger.Insights.Absinthe.html#handle_telemetry/4","title":"Honeybadger.Insights.Absinthe.handle_telemetry/4","type":"function"},{"doc":"Determines if an event should be ignored based on its metadata.\nChild modules should override this for specific filtering logic.\nNote: this is the metadata before any transformations.","ref":"Honeybadger.Insights.Absinthe.html#ignore?/1","title":"Honeybadger.Insights.Absinthe.ignore?/1","type":"function"},{"doc":"Process the event data. Child modules can override this for custom\nprocessing.","ref":"Honeybadger.Insights.Absinthe.html#process_event/1","title":"Honeybadger.Insights.Absinthe.process_event/1","type":"function"},{"doc":"Base module providing common telemetry attachment functionality.","ref":"Honeybadger.Insights.Base.html","title":"Honeybadger.Insights.Base","type":"module"},{"doc":"Checks if all required dependencies are available.","ref":"Honeybadger.Insights.Base.html#dependencies_available?/1","title":"Honeybadger.Insights.Base.dependencies_available?/1","type":"function"},{"doc":"Retrieves a configuration value from the insights configuration.","ref":"Honeybadger.Insights.Base.html#get_insights_config/3","title":"Honeybadger.Insights.Base.get_insights_config/3","type":"function"},{"doc":"Captures database query telemetry events from Ecto repositories.","ref":"Honeybadger.Insights.Ecto.html","title":"Honeybadger.Insights.Ecto","type":"module"},{"doc":"By default, this module listens for telemetry events from all configured\nEcto repositories. It reads the `:ecto_repos` configuration to identify\nrepositories and their telemetry prefixes.","ref":"Honeybadger.Insights.Ecto.html#module-default-configuration","title":"Default Configuration - Honeybadger.Insights.Ecto","type":"module"},{"doc":"You can customize this module's behavior with the following configuration options:\n\n    config :honeybadger, insights_config: %{\n      ecto: %{\n        # A list of strings or regex patterns of queries to exclude\n        excluded_queries: [\n          ~r/^(begin|commit)( immediate)?( transaction)?$/i,\n          ~r/SELECT pg_notify/,\n          ~r/schema_migrations/\n        ],\n\n        # Format & include the stacktrace with each query. You must also\n        # update your repo config to enable:\n        #\n        #   config :my_app, MyApp.Repo,\n        #     stacktrace: true\n        #\n        # Can be a boolean to enable for all or a list of sources to enable.\n        include_stacktrace: true\n\n        # Alternative source whitelist example:\n        # include_stacktrace: [\"source_a\", \"source_b\"],\n\n        # Format & include the query parameters with each query. Can be a\n        # boolean to enable for all or a list of sources to enable.\n        include_params: true\n\n        # Alternative source whitelist example:\n        # include_params:[\"source_a\", \"source_b\"],\n\n        # A list of table/source names to exclude\n        excluded_sources: [\n          \"schema_migrations\",\n          \"oban_jobs\",\n          \"oban_peers\"\n        ]\n      }\n    }\n\nBy default, transaction bookkeeping queries and schema migration checks are excluded,\nas well as queries to common background job tables.","ref":"Honeybadger.Insights.Ecto.html#module-custom-configuration","title":"Custom Configuration - Honeybadger.Insights.Ecto","type":"module"},{"doc":"Attaches telemetry handlers if all required dependencies are available.","ref":"Honeybadger.Insights.Ecto.html#attach/0","title":"Honeybadger.Insights.Ecto.attach/0","type":"function"},{"doc":"Attaches a telemetry handler for a specific event.","ref":"Honeybadger.Insights.Ecto.html#attach_event/1","title":"Honeybadger.Insights.Ecto.attach_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Ecto.html#dependencies_available?/0","title":"Honeybadger.Insights.Ecto.dependencies_available?/0","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Ecto.html#event_filter/3","title":"Honeybadger.Insights.Ecto.event_filter/3","type":"function"},{"doc":"Extracts metadata from the telemetry event.\nChild modules should override this for specific events.","ref":"Honeybadger.Insights.Ecto.html#extract_metadata/2","title":"Honeybadger.Insights.Ecto.extract_metadata/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Ecto.html#get_insights_config/2","title":"Honeybadger.Insights.Ecto.get_insights_config/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Ecto.html#get_telemetry_events/0","title":"Honeybadger.Insights.Ecto.get_telemetry_events/0","type":"function"},{"doc":"Implementation of handle_telemetry that can be called by overriding methods.","ref":"Honeybadger.Insights.Ecto.html#handle_event_impl/4","title":"Honeybadger.Insights.Ecto.handle_event_impl/4","type":"function"},{"doc":"Handles telemetry events and processes the data.\nThis implementation forwards to handle_event_impl which can be overridden\nby child modules to customize behavior while still calling the parent implementation.","ref":"Honeybadger.Insights.Ecto.html#handle_telemetry/4","title":"Honeybadger.Insights.Ecto.handle_telemetry/4","type":"function"},{"doc":"Determines if an event should be ignored based on its metadata.\nChild modules should override this for specific filtering logic.\nNote: this is the metadata before any transformations.","ref":"Honeybadger.Insights.Ecto.html#ignore?/1","title":"Honeybadger.Insights.Ecto.ignore?/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Ecto.html#obfuscate/2","title":"Honeybadger.Insights.Ecto.obfuscate/2","type":"function"},{"doc":"Process the event data. Child modules can override this for custom\nprocessing.","ref":"Honeybadger.Insights.Ecto.html#process_event/1","title":"Honeybadger.Insights.Ecto.process_event/1","type":"function"},{"doc":"Captures telemetry events from HTTP requests made using Finch.","ref":"Honeybadger.Insights.Finch.html","title":"Honeybadger.Insights.Finch","type":"module"},{"doc":"By default, this module listens for the standard Finch request telemetry event:\n\n    \"finch.request.stop\"","ref":"Honeybadger.Insights.Finch.html#module-default-configuration","title":"Default Configuration - Honeybadger.Insights.Finch","type":"module"},{"doc":"You can customize the telemetry events to listen for by updating the insights_config:\n\n    config :honeybadger, insights_config: %{\n      finch: %{\n        telemetry_events: [\"finch.request.stop\", \"finch.request.exception\"],\n\n        # Include full URLs in telemetry events (default: false - only hostname is included)\n        full_url: false\n      }\n    }\n\nBy default, only the hostname from URLs is captured for security and privacy reasons.\nIf you need to capture the full URL including paths (but not query parameters),\nyou can enable the `full_url` option.","ref":"Honeybadger.Insights.Finch.html#module-custom-configuration","title":"Custom Configuration - Honeybadger.Insights.Finch","type":"module"},{"doc":"Attaches telemetry handlers if all required dependencies are available.","ref":"Honeybadger.Insights.Finch.html#attach/0","title":"Honeybadger.Insights.Finch.attach/0","type":"function"},{"doc":"Attaches a telemetry handler for a specific event.","ref":"Honeybadger.Insights.Finch.html#attach_event/1","title":"Honeybadger.Insights.Finch.attach_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Finch.html#dependencies_available?/0","title":"Honeybadger.Insights.Finch.dependencies_available?/0","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Finch.html#event_filter/3","title":"Honeybadger.Insights.Finch.event_filter/3","type":"function"},{"doc":"Extracts metadata from the telemetry event.\nChild modules should override this for specific events.","ref":"Honeybadger.Insights.Finch.html#extract_metadata/2","title":"Honeybadger.Insights.Finch.extract_metadata/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Finch.html#get_insights_config/2","title":"Honeybadger.Insights.Finch.get_insights_config/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Finch.html#get_telemetry_events/0","title":"Honeybadger.Insights.Finch.get_telemetry_events/0","type":"function"},{"doc":"Implementation of handle_telemetry that can be called by overriding methods.","ref":"Honeybadger.Insights.Finch.html#handle_event_impl/4","title":"Honeybadger.Insights.Finch.handle_event_impl/4","type":"function"},{"doc":"Handles telemetry events and processes the data.\nThis implementation forwards to handle_event_impl which can be overridden\nby child modules to customize behavior while still calling the parent implementation.","ref":"Honeybadger.Insights.Finch.html#handle_telemetry/4","title":"Honeybadger.Insights.Finch.handle_telemetry/4","type":"function"},{"doc":"Determines if an event should be ignored based on its metadata.\nChild modules should override this for specific filtering logic.\nNote: this is the metadata before any transformations.","ref":"Honeybadger.Insights.Finch.html#ignore?/1","title":"Honeybadger.Insights.Finch.ignore?/1","type":"function"},{"doc":"Process the event data. Child modules can override this for custom\nprocessing.","ref":"Honeybadger.Insights.Finch.html#process_event/1","title":"Honeybadger.Insights.Finch.process_event/1","type":"function"},{"doc":"Captures telemetry events from Phoenix LiveView.","ref":"Honeybadger.Insights.LiveView.html","title":"Honeybadger.Insights.LiveView","type":"module"},{"doc":"By default, this module listens for the following LiveView telemetry events:\n\n   \"phoenix.live_view.mount.stop\"\n   \"phoenix.live_component.handle_event.stop\"\n   \"phoenix.live_view.update.stop\"","ref":"Honeybadger.Insights.LiveView.html#module-default-configuration","title":"Default Configuration - Honeybadger.Insights.LiveView","type":"module"},{"doc":"You can customize the telemetry events to listen for by updating the insights_config:\n\n   config :honeybadger, insights_config: %{\n     live_view: %{\n       telemetry_events: [\n         [:phoenix, :live_view, :mount, :stop],\n         [:phoenix, :live_component, :handle_event, :stop],\n         [:phoenix, :live_component, :update, :stop]\n         [:phoenix, :live_view, :handle_event, :stop],\n         [:phoenix, :live_view, :handle_params, :stop],\n         [:phoenix, :live_view, :update, :stop]\n       ]\n     }\n   }","ref":"Honeybadger.Insights.LiveView.html#module-custom-configuration","title":"Custom Configuration - Honeybadger.Insights.LiveView","type":"module"},{"doc":"Attaches telemetry handlers if all required dependencies are available.","ref":"Honeybadger.Insights.LiveView.html#attach/0","title":"Honeybadger.Insights.LiveView.attach/0","type":"function"},{"doc":"Attaches a telemetry handler for a specific event.","ref":"Honeybadger.Insights.LiveView.html#attach_event/1","title":"Honeybadger.Insights.LiveView.attach_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.LiveView.html#dependencies_available?/0","title":"Honeybadger.Insights.LiveView.dependencies_available?/0","type":"function"},{"doc":"","ref":"Honeybadger.Insights.LiveView.html#event_filter/3","title":"Honeybadger.Insights.LiveView.event_filter/3","type":"function"},{"doc":"Extracts metadata from the telemetry event.\nChild modules should override this for specific events.","ref":"Honeybadger.Insights.LiveView.html#extract_metadata/2","title":"Honeybadger.Insights.LiveView.extract_metadata/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.LiveView.html#get_insights_config/2","title":"Honeybadger.Insights.LiveView.get_insights_config/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.LiveView.html#get_telemetry_events/0","title":"Honeybadger.Insights.LiveView.get_telemetry_events/0","type":"function"},{"doc":"Implementation of handle_telemetry that can be called by overriding methods.","ref":"Honeybadger.Insights.LiveView.html#handle_event_impl/4","title":"Honeybadger.Insights.LiveView.handle_event_impl/4","type":"function"},{"doc":"Handles telemetry events and processes the data.\nThis implementation forwards to handle_event_impl which can be overridden\nby child modules to customize behavior while still calling the parent implementation.","ref":"Honeybadger.Insights.LiveView.html#handle_telemetry/4","title":"Honeybadger.Insights.LiveView.handle_telemetry/4","type":"function"},{"doc":"Determines if an event should be ignored based on its metadata.\nChild modules should override this for specific filtering logic.\nNote: this is the metadata before any transformations.","ref":"Honeybadger.Insights.LiveView.html#ignore?/1","title":"Honeybadger.Insights.LiveView.ignore?/1","type":"function"},{"doc":"Process the event data. Child modules can override this for custom\nprocessing.","ref":"Honeybadger.Insights.LiveView.html#process_event/1","title":"Honeybadger.Insights.LiveView.process_event/1","type":"function"},{"doc":"Captures telemetry events from Oban job processing.","ref":"Honeybadger.Insights.Oban.html","title":"Honeybadger.Insights.Oban","type":"module"},{"doc":"By default, this module listens for the following Oban telemetry events:\n\n   \"oban.job.stop\"\n   \"oban.job.exception\"","ref":"Honeybadger.Insights.Oban.html#module-default-configuration","title":"Default Configuration - Honeybadger.Insights.Oban","type":"module"},{"doc":"You can customize the telemetry events to listen for by updating the insights_config:\n\n   config :honeybadger, insights_config: %{\n     oban: %{\n       telemetry_events: [\n         [:oban, :job, :stop],\n         [:oban, :job, :exception],\n         [:oban, :engine, :start]\n       ]\n     }\n   }","ref":"Honeybadger.Insights.Oban.html#module-custom-configuration","title":"Custom Configuration - Honeybadger.Insights.Oban","type":"module"},{"doc":"Adds the current Honeybadger event context to the Oban job's metadata.","ref":"Honeybadger.Insights.Oban.html#add_event_context/1","title":"Honeybadger.Insights.Oban.add_event_context/1","type":"function"},{"doc":"MyApp.Worker.new()\n    |> Honeybadger.Insights.Oban.add_event_context()\n    |> Oban.insert()","ref":"Honeybadger.Insights.Oban.html#add_event_context/1-example","title":"Example - Honeybadger.Insights.Oban.add_event_context/1","type":"function"},{"doc":"Attaches telemetry handlers if all required dependencies are available.","ref":"Honeybadger.Insights.Oban.html#attach/0","title":"Honeybadger.Insights.Oban.attach/0","type":"function"},{"doc":"Attaches a telemetry handler for a specific event.","ref":"Honeybadger.Insights.Oban.html#attach_event/1","title":"Honeybadger.Insights.Oban.attach_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Oban.html#dependencies_available?/0","title":"Honeybadger.Insights.Oban.dependencies_available?/0","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Oban.html#event_filter/3","title":"Honeybadger.Insights.Oban.event_filter/3","type":"function"},{"doc":"Extracts metadata from the telemetry event.\nChild modules should override this for specific events.","ref":"Honeybadger.Insights.Oban.html#extract_metadata/2","title":"Honeybadger.Insights.Oban.extract_metadata/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Oban.html#get_insights_config/2","title":"Honeybadger.Insights.Oban.get_insights_config/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Oban.html#get_telemetry_events/0","title":"Honeybadger.Insights.Oban.get_telemetry_events/0","type":"function"},{"doc":"Implementation of handle_telemetry that can be called by overriding methods.","ref":"Honeybadger.Insights.Oban.html#handle_event_impl/4","title":"Honeybadger.Insights.Oban.handle_event_impl/4","type":"function"},{"doc":"Handles telemetry events and processes the data.\nThis implementation forwards to handle_event_impl which can be overridden\nby child modules to customize behavior while still calling the parent implementation.","ref":"Honeybadger.Insights.Oban.html#handle_telemetry/4","title":"Honeybadger.Insights.Oban.handle_telemetry/4","type":"function"},{"doc":"Determines if an event should be ignored based on its metadata.\nChild modules should override this for specific filtering logic.\nNote: this is the metadata before any transformations.","ref":"Honeybadger.Insights.Oban.html#ignore?/1","title":"Honeybadger.Insights.Oban.ignore?/1","type":"function"},{"doc":"Process the event data. Child modules can override this for custom\nprocessing.","ref":"Honeybadger.Insights.Oban.html#process_event/1","title":"Honeybadger.Insights.Oban.process_event/1","type":"function"},{"doc":"Captures telemetry events from HTTP requests processed by Plug and Phoenix.","ref":"Honeybadger.Insights.Plug.html","title":"Honeybadger.Insights.Plug","type":"module"},{"doc":"By default, this module listens for the standard Phoenix endpoint telemetry event:\n\n    \"phoenix.endpoint.stop\"\n\nThis is compatible with the default Phoenix configuration that adds telemetry\nvia `Plug.Telemetry`:\n\n    plug Plug.Telemetry, event_prefix: [:phoenix, :endpoint]","ref":"Honeybadger.Insights.Plug.html#module-default-configuration","title":"Default Configuration - Honeybadger.Insights.Plug","type":"module"},{"doc":"You can customize the telemetry events to listen for by updating the insights_config:\n\n    config :honeybadger, insights_config: %{\n      plug: %{\n        telemetry_events: [[:my, :prefix, :stop]]\n      }\n    }","ref":"Honeybadger.Insights.Plug.html#module-custom-configuration","title":"Custom Configuration - Honeybadger.Insights.Plug","type":"module"},{"doc":"Attaches telemetry handlers if all required dependencies are available.","ref":"Honeybadger.Insights.Plug.html#attach/0","title":"Honeybadger.Insights.Plug.attach/0","type":"function"},{"doc":"Attaches a telemetry handler for a specific event.","ref":"Honeybadger.Insights.Plug.html#attach_event/1","title":"Honeybadger.Insights.Plug.attach_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Plug.html#dependencies_available?/0","title":"Honeybadger.Insights.Plug.dependencies_available?/0","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Plug.html#event_filter/3","title":"Honeybadger.Insights.Plug.event_filter/3","type":"function"},{"doc":"Extracts metadata from the telemetry event.\nChild modules should override this for specific events.","ref":"Honeybadger.Insights.Plug.html#extract_metadata/2","title":"Honeybadger.Insights.Plug.extract_metadata/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Plug.html#get_insights_config/2","title":"Honeybadger.Insights.Plug.get_insights_config/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Plug.html#get_telemetry_events/0","title":"Honeybadger.Insights.Plug.get_telemetry_events/0","type":"function"},{"doc":"Implementation of handle_telemetry that can be called by overriding methods.","ref":"Honeybadger.Insights.Plug.html#handle_event_impl/4","title":"Honeybadger.Insights.Plug.handle_event_impl/4","type":"function"},{"doc":"Handles telemetry events and processes the data.\nThis implementation forwards to handle_event_impl which can be overridden\nby child modules to customize behavior while still calling the parent implementation.","ref":"Honeybadger.Insights.Plug.html#handle_telemetry/4","title":"Honeybadger.Insights.Plug.handle_telemetry/4","type":"function"},{"doc":"Determines if an event should be ignored based on its metadata.\nChild modules should override this for specific filtering logic.\nNote: this is the metadata before any transformations.","ref":"Honeybadger.Insights.Plug.html#ignore?/1","title":"Honeybadger.Insights.Plug.ignore?/1","type":"function"},{"doc":"Process the event data. Child modules can override this for custom\nprocessing.","ref":"Honeybadger.Insights.Plug.html#process_event/1","title":"Honeybadger.Insights.Plug.process_event/1","type":"function"},{"doc":"Captures telemetry events from Tesla HTTP requests.","ref":"Honeybadger.Insights.Tesla.html","title":"Honeybadger.Insights.Tesla","type":"module"},{"doc":"This module can be configured in the application config:\n\n```elixir\nconfig :honeybadger, insights_config: %{\n  tesla: %{\n    # Include full URLs in telemetry events (default: false - only hostname is included)\n    full_url: false,\n\n    # Custom telemetry event patterns to listen for (optional)\n    telemetry_events: [[:tesla, :request, :stop], [:tesla, :request, :exception]]\n  }\n}","ref":"Honeybadger.Insights.Tesla.html#module-configuration","title":"Configuration - Honeybadger.Insights.Tesla","type":"module"},{"doc":"Attaches telemetry handlers if all required dependencies are available.","ref":"Honeybadger.Insights.Tesla.html#attach/0","title":"Honeybadger.Insights.Tesla.attach/0","type":"function"},{"doc":"Attaches a telemetry handler for a specific event.","ref":"Honeybadger.Insights.Tesla.html#attach_event/1","title":"Honeybadger.Insights.Tesla.attach_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Tesla.html#dependencies_available?/0","title":"Honeybadger.Insights.Tesla.dependencies_available?/0","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Tesla.html#event_filter/3","title":"Honeybadger.Insights.Tesla.event_filter/3","type":"function"},{"doc":"Extracts metadata from the telemetry event.\nChild modules should override this for specific events.","ref":"Honeybadger.Insights.Tesla.html#extract_metadata/2","title":"Honeybadger.Insights.Tesla.extract_metadata/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Tesla.html#get_insights_config/2","title":"Honeybadger.Insights.Tesla.get_insights_config/2","type":"function"},{"doc":"","ref":"Honeybadger.Insights.Tesla.html#get_telemetry_events/0","title":"Honeybadger.Insights.Tesla.get_telemetry_events/0","type":"function"},{"doc":"Implementation of handle_telemetry that can be called by overriding methods.","ref":"Honeybadger.Insights.Tesla.html#handle_event_impl/4","title":"Honeybadger.Insights.Tesla.handle_event_impl/4","type":"function"},{"doc":"Handles telemetry events and processes the data.\nThis implementation forwards to handle_event_impl which can be overridden\nby child modules to customize behavior while still calling the parent implementation.","ref":"Honeybadger.Insights.Tesla.html#handle_telemetry/4","title":"Honeybadger.Insights.Tesla.handle_telemetry/4","type":"function"},{"doc":"Determines if an event should be ignored based on its metadata.\nChild modules should override this for specific filtering logic.\nNote: this is the metadata before any transformations.","ref":"Honeybadger.Insights.Tesla.html#ignore?/1","title":"Honeybadger.Insights.Tesla.ignore?/1","type":"function"},{"doc":"Process the event data. Child modules can override this for custom\nprocessing.","ref":"Honeybadger.Insights.Tesla.html#process_event/1","title":"Honeybadger.Insights.Tesla.process_event/1","type":"function"},{"doc":"","ref":"Honeybadger.Notice.html","title":"Honeybadger.Notice","type":"module"},{"doc":"","ref":"Honeybadger.Notice.html#t:error/0","title":"Honeybadger.Notice.error/0","type":"type"},{"doc":"","ref":"Honeybadger.Notice.html#new/4","title":"Honeybadger.Notice.new/4","type":"function"},{"doc":"","ref":"Honeybadger.Notice.html#t:noticeable/0","title":"Honeybadger.Notice.noticeable/0","type":"type"},{"doc":"","ref":"Honeybadger.Notice.html#t:notifier/0","title":"Honeybadger.Notice.notifier/0","type":"type"},{"doc":"","ref":"Honeybadger.Notice.html#t:server/0","title":"Honeybadger.Notice.server/0","type":"type"},{"doc":"","ref":"Honeybadger.Notice.html#t:t/0","title":"Honeybadger.Notice.t/0","type":"type"},{"doc":"Specification for a top level `Honeybadger.Notice` filter.\n\nMost users won't need this, but if you need complete control over\nfiltering, implement this behaviour and configure like:\n\n    config :honeybadger,\n      notice_filter: MyApp.MyNoticeFilter","ref":"Honeybadger.NoticeFilter.html","title":"Honeybadger.NoticeFilter","type":"behaviour"},{"doc":"","ref":"Honeybadger.NoticeFilter.html#c:filter/1","title":"Honeybadger.NoticeFilter.filter/1","type":"callback"},{"doc":"","ref":"Honeybadger.NoticeFilter.Default.html","title":"Honeybadger.NoticeFilter.Default","type":"module"},{"doc":"","ref":"Honeybadger.NoticeFilter.Default.html#filter/1","title":"Honeybadger.NoticeFilter.Default.filter/1","type":"function"},{"doc":"The `Honeybadger.Plug` adds automatic error handling to a plug pipeline.\n\nWithin a `Plug.Router` or `Phoenix.Router` use the module and crashes will\nbe reported to Honeybadger. It's best to `use Honeybadger.Plug` **after\nthe Router plugs** so that exceptions due to non-matching routes are not\nreported to Honeybadger.","ref":"Honeybadger.Plug.html","title":"Honeybadger.Plug","type":"module"},{"doc":"defmodule MyPhoenixApp.Router do\n      use Crywolf.Web, :router\n      use Honeybadger.Plug\n\n      pipeline :browser do\n        [...]\n      end\n    end","ref":"Honeybadger.Plug.html#module-example","title":"Example - Honeybadger.Plug","type":"module"},{"doc":"Data reporting may be customized by passing an alternate `:plug_data`\nmodule. This is useful when working with alternate frameworks, such as\nAbsinthe for GraphQL APIs.\n\nAny module with a `metadata/2` function that accepts a `Plug.Conn` and a\n`module` name can be used to generate metadata.","ref":"Honeybadger.Plug.html#module-customizing","title":"Customizing - Honeybadger.Plug","type":"module"},{"doc":"defmodule MyPhoenixApp.Router do\n      use Crywolf.Web, :router\n      use Honeybadger.Plug, plug_data: MyAbsinthePlugData\n    end","ref":"Honeybadger.Plug.html#module-example","title":"Example - Honeybadger.Plug","type":"module"},{"doc":"Assorted helper functions used through out the Honeybadger package.","ref":"Honeybadger.Utils.html","title":"Honeybadger.Utils","type":"module"},{"doc":"Transform value into a consistently cased string representation\n\n# Example\n\n    iex> Honeybadger.Utils.canonicalize(:User_SSN)\n    \"user_ssn\"","ref":"Honeybadger.Utils.html#canonicalize/1","title":"Honeybadger.Utils.canonicalize/1","type":"function"},{"doc":"Concatenate a list of items with a dot separator.\n\n# Example\n\n    iex> Honeybadger.Utils.dotify([:Honeybadger, :Utils])\n    \"Honeybadger.Utils\"","ref":"Honeybadger.Utils.html#dotify/1","title":"Honeybadger.Utils.dotify/1","type":"function"},{"doc":"Internally all modules are prefixed with Elixir. This function removes the\n`Elixir` prefix from the module when it is converted to a string.\n\n# Example\n\n    iex> Honeybadger.Utils.module_to_string(Honeybadger.Utils)\n    \"Honeybadger.Utils\"","ref":"Honeybadger.Utils.html#module_to_string/1","title":"Honeybadger.Utils.module_to_string/1","type":"function"},{"doc":"","ref":"Honeybadger.Utils.html#rand_id/1","title":"Honeybadger.Utils.rand_id/1","type":"function"},{"doc":"Configurable data sanitization. This currently:\n\n- recursively truncates deep structures (to a depth of 20)\n- constrains large string values (to 64k)\n- filters out any map keys that might contain sensitive information.\n\nOptions:\n- `:remove_filtered` - When `true`, filtered keys will be removed instead of replaced with \"[FILTERED]\". Default: `false`","ref":"Honeybadger.Utils.html#sanitize/2","title":"Honeybadger.Utils.sanitize/2","type":"function"},{"doc":"release uses shipit.\nIt performs many sanity checks before pushing the hex package.\nCheck out https://github.com/wojtekmach/shipit for more details","ref":"Mix.Tasks.HexRelease.html","title":"mix hex_release","type":"task"},{"doc":"","ref":"Mix.Tasks.HexRelease.html#run/1","title":"Mix.Tasks.HexRelease.run/1","type":"function"},{"doc":"","ref":"Mix.Tasks.Honeybadger.Test.html","title":"mix honeybadger.test","type":"task"},{"doc":"","ref":"Mix.Tasks.Honeybadger.Test.html#run/1","title":"Mix.Tasks.Honeybadger.Test.run/1","type":"function"},{"doc":"","ref":"Honeybadger.InvalidResponseError.html","title":"Honeybadger.InvalidResponseError","type":"exception"},{"doc":"","ref":"Honeybadger.InvalidResponseError.html#message/1","title":"Honeybadger.InvalidResponseError.message/1","type":"function"},{"doc":"","ref":"Honeybadger.InvalidResponseError.html#t:t/0","title":"Honeybadger.InvalidResponseError.t/0","type":"type"},{"doc":"","ref":"Honeybadger.MissingEnvironmentNameError.html","title":"Honeybadger.MissingEnvironmentNameError","type":"exception"},{"doc":"","ref":"Honeybadger.ServerUnreachableError.html","title":"Honeybadger.ServerUnreachableError","type":"exception"},{"doc":"","ref":"Honeybadger.ServerUnreachableError.html#message/1","title":"Honeybadger.ServerUnreachableError.message/1","type":"function"},{"doc":"","ref":"Honeybadger.ServerUnreachableError.html#t:t/0","title":"Honeybadger.ServerUnreachableError.t/0","type":"type"},{"doc":"","ref":"HoneybadgerTestingException.html","title":"HoneybadgerTestingException","type":"exception"},{"doc":"# Honeybadger for Elixir\n\n![Elixir CI](https://github.com/honeybadger-io/honeybadger-elixir/workflows/Elixir%20CI/badge.svg?branch=master)\n\nElixir Plug, Logger and client for the :zap: [Honeybadger error notifier](https://www.honeybadger.io/).\n\n**Upgrading to v0.11?** [See the release notes](https://github.com/honeybadger-io/honeybadger-elixir/blob/master/CHANGELOG.md#v0110---2019-02-28)","ref":"readme.html","title":"Honeybadger for Elixir","type":"extras"},{"doc":"[ ](https://honeybadger.wistia.com/medias/krtqjywtp3)\n\n[Watch our screencast](https://honeybadger.wistia.com/medias/krtqjywtp3) by Josh Adams of [ElixirSips](http://elixirsips.com/)!","ref":"readme.html#getting-started","title":"Getting Started - Honeybadger for Elixir","type":"extras"},{"doc":"- Erlang >= 24.0\n- Elixir >= 1.15\n- Plug >= 1.10\n- Phoenix >= 1.0 (This is an optional dependency and the version requirement applies only if you are using Phoenix)","ref":"readme.html#version-requirements","title":"Version Requirements - Honeybadger for Elixir","type":"extras"},{"doc":"Add the Honeybadger package to `deps/0` in your\napplication's `mix.exs`:\n\n```elixir\ndefp deps do\n  [{:honeybadger, \"~> 0.22\"}]\nend\n```\n\nThen run:\n\n```sh\nmix do deps.get, deps.compile\n```","ref":"readme.html#1-install-the-package","title":"1. Install the package - Honeybadger for Elixir","type":"extras"},{"doc":"By default, the environment variable `HONEYBADGER_API_KEY` will be used to\nreport errors to the Honeybadger API:\n\n```sh\nexport HONEYBADGER_API_KEY={{PROJECT_API_KEY}}\n```\n\nYou can alternatively configure Honeybadger settings in `config.exs`:\n\n```elixir\nconfig :honeybadger,\n  api_key: \"{{PROJECT_API_KEY}}\"\n```\n\nWe also need to set the name of the environment for each environment. This\nensures that we can accurately report the environment that an error occurs in.\nYou can add something like the following to each of your `#{env}.exs` files:\n\n```elixir\nconfig :honeybadger,\n  environment_name: :dev\n```\n\nIf `environment_name` is not set we will fall back to the value of `Mix.env()`.\n`Mix.env()` uses the atomized value of the `MIX_ENV` environment variable and\ndefaults to `:prod` when the environment variable is not set. This should be good\nfor most setups. If you want to have an `environment_name` which is different than\nthe `Mix.env()`, you should set `environment_name` in your `config.exs` files for each\nenvironment. This ensures that we can give you accurate environment information\neven during compile time. Explicitly setting the `environment_name` config\ntakes higher precedence over the `Mix.env()` value.","ref":"readme.html#2-set-your-api-key-and-environment-name","title":"2. Set your API key and environment name - Honeybadger for Elixir","type":"extras"},{"doc":"-> **Note:** Honeybadger does not report errors in `dev` and `test` environments by default. To enable reporting in development environments, temporarily add `exclude_envs: []` to your Honeybadger config.\n\nTo report a test error to Honeybadger, fire up `iex -S mix`, then run:\n\n```elixir\nHoneybadger.notify(\"Hello Elixir!\")\n```\n\nAfter you've tested your Honeybadger installation, you may want to configure one or more of the following integrations to automatically report errors.","ref":"readme.html#3-report-a-test-error","title":"3. Report a test error - Honeybadger for Elixir","type":"extras"},{"doc":"The Honeybadger package can be used as a Plug alongside your Phoenix\napplications, as a logger backend, or as a standalone client for sprinkling in\nexception notifications where they are needed.\n\n#### Phoenix and Plug\n\nThe Honeybadger Plug adds a\n[Plug.ErrorHandler](https://github.com/elixir-lang/plug/blob/master/lib/plug/error_handler.ex)\nto your pipeline. Simply `use` the `Honeybadger.Plug` module inside of a Plug\nor Phoenix.Router and any crashes will be automatically reported to\nHoneybadger. It's best to `use Honeybadger.Plug` **after the Router plugs** so that\nexceptions due to non-matching routes are not reported to Honeybadger.\n\n##### Phoenix app\n\n```elixir\ndefmodule MyPhoenixApp.Router do\n  use Crywolf.Web, :router\n  use Honeybadger.Plug\n\n  pipeline :browser do\n    [...]\n  end\nend\n```\n\n##### Plug app\n\n```elixir\ndefmodule MyPlugApp do\n  use Plug.Router\n  use Honeybadger.Plug\n\n  [... the rest of your plug ...]\nend\n```\n\n#### Logger\n\nJust set the `use_logger` option to `true` in your application's `config.exs`\nand you're good to go:\n\n```elixir\nconfig :honeybadger,\n  use_logger: true\n```\n\nAny\n[SASL](http://www.erlang.org/doc/apps/sasl/error_logging.html) compliant\nprocesses that crash will send an error report to the `Honeybadger.Logger`.\nAfter the error reaches the logger we take care of notifying Honeybadger for\nyou!\n\n#### Manual reporting\n\nYou can manually report rescued exceptions with the  `Honeybadger.notify` function.\n\n```elixir\ntry do\n  File.read! \"this_file_really_should_exist_dang_it.txt\"\nrescue\n  exception ->\n    Honeybadger.notify(exception, metadata: %{}, stacktrace: __STACKTRACE__, fingerprint: \"\")\nend\n```","ref":"readme.html#4-enable-automatic-error-reporting","title":"4. Enable automatic error reporting - Honeybadger for Elixir","type":"extras"},{"doc":"Honeybadger Insights allows you to automatically track various events in your\napplication. To enable Insights automatic instrumentation, add the following to\nyour configuration:\n\n```elixir\nconfig :honeybadger,\n  insights_enabled: true\n```","ref":"readme.html#insights-automatic-instrumentation","title":"Insights Automatic Instrumentation - Honeybadger for Elixir","type":"extras"},{"doc":"Honeybadger automatically instruments the following libraries when they are available:\n\n* Absinthe: GraphQL query execution\n* Ecto: Database queries\n* Finch: HTTP client requests, often used by other libraries like Req\n* Tesla: HTTP client requests\n* LiveView: Phoenix LiveView lifecycle events\n* Oban: Background job processing\n* Plug/Phoenix: HTTP requests","ref":"readme.html#supported-libraries","title":"Supported Libraries - Honeybadger for Elixir","type":"extras"},{"doc":"Each library can be configured individually using the `insights_config` option:\n\n```elixir\nconfig :honeybadger, insights_config: %{\n  # Ecto configuration\n  ecto: %{\n    # A list of strings or regex patterns of queries to exclude\n    excluded_queries: [~r/^(begin|commit)/i],\n\n    # A list of table/source names to exclude\n    excluded_sources: [\"schema_migrations\"]\n  },\n\n  # Finch/Tesla configuration\n  finch: %{\n    # Include full URLs instead of just hostnames\n    full_url: false\n  },\n\n  # Plug configuration\n  plug: %{\n    telemetry_events: [[:phoenix, :endpoint, :stop]]\n  },\n\n  # LiveView configuration\n  live_view: %{\n    telemetry_events: [\n      [:phoenix, :live_view, :mount, :stop],\n      [:phoenix, :live_view, :update, :stop]\n    ]\n  },\n\n  # Absinthe configuration\n  absinthe: %{\n    telemetry_events: [\n      [:absinthe, :execute, :operation, :start],\n      [:absinthe, :execute, :operation, :stop],\n      [:absinthe, :execute, :operation, :exception]\n    ]\n  },\n\n  # Oban configuration\n  oban: %{\n    telemetry_events: [\n      [:oban, :job, :stop],\n      [:oban, :job, :exception]\n    ]\n  }\n}\n```","ref":"readme.html#custom-configuration","title":"Custom Configuration - Honeybadger for Elixir","type":"extras"},{"doc":"You can filter out or customize events sent to Honeybadger Insights by\nusing the `Honeybadger.EventFilter.Mixin` module. You can customize both\nthe event built from telemetry data (`filter_telemetry_event/3`) and the event\nright before it is sent to Honeybadger (`filter_event/1`):\n\n```elixir\ndefmodule MyApp.MyFilter do\n  use Honeybadger.EventFilter.Mixin\n\n  # Drop analytics events by returning nil\n  def filter_event(%{event_type: \"analytics\"} = _event), do: nil\n\n  # Anonymize user data in login events\n  def filter_event(%{event_type: \"login\"} = event) do\n    event\n    |> update_in([:data, :user_email], fn _ -> \"[REDACTED]\" end)\n    |> put_in([:metadata, :filtered], true)\n  end\n\n  # For telemetry events, you can customize while still applying default filtering\n  def filter_telemetry_event(data, raw, event) do\n    # First apply default filtering\n    filtered_data = apply_default_telemetry_filtering(data)\n\n    # Then apply custom logic\n    case event do\n      [:auth, :login, :start] ->\n        Map.put(filtered_data, :security_filtered, true)\n      _ ->\n        filtered_data\n    end\n  end\n\n  # Keep all other events as they are\n  def filter_event(event), do: event\nend\n```\n\nThen configure the filter in your application's configuration:\n\n```elixir\nconfig :honeybadger, event_filter: MyApp.EventFilter\n```","ref":"readme.html#event-filtering","title":"Event Filtering - Honeybadger for Elixir","type":"extras"},{"doc":"You can add custom metadata to the events sent to Honeybadger Insights by\nusing the `event_context/1` function. This metadata will be included in each\nevent call within the same process.\n\nNote: This will add the metadata to all events sent, so be careful not to\ninclude too much data. Try to keep it to simple key/value pairs.\n\nFor example, you can add user ID information to all events (via plug):\n\n```elixir\ndefmodule MyAppWeb.Plug.UserContext do\n  import Plug.Conn\n\n  def init(opts), do: opts\n\n  def call(conn, _opts) do\n    user = get_session(conn, :user)\n    Honeybadger.event_context(%{user_id: user.id})\n    conn\n  end\nend\n```\n\nEvent context is not automatically propagated to other processes. If you want to\nadd context to events in a different process, you can use the\n`Honeybadger.event_context/0` function to get the current context and pass it\nto the `Honeybadger.event/1` function:\n\n```elixir\ndefmodule MyApp.MyGenServer do\n  use GenServer\n\n  def set(value) do\n    GenServer.cast(__MODULE__, {:set, value, Honeybadger.event_context()})\n  end\n\n  def handle_cast({:set, value, hb_context}, _state) do\n    Honeybadger.event_context(hb_context)\n\n    Honeybadger.event(\"set_value\", %{value: value})\n    {:noreply, value}\n  end\nend\n```\n\nIf you know the parent process is alive and part of the process tree, you can\nuse `Honeybadger.inherit_event_context/0` to inherit the context from the\nparent process. This method works best if you are running OTP 25+.\n\n```elixir\nTask.async(fn ->\n  Honeybadger.inherit_event_context()\n  # Do some work here\n  Honeybadger.event(\"work\", %{did: \"some_work\"})\nend)\n```\n\nScenarios when inheriting context is useful include:\n\n- Direct process spawning (`spawn`, `spawn_link`)\n- `Task.async/1`, `Task.await/1`, etc.\n- Other scenarios where direct parent-child relationships are maintained\n\nWhen explicit passing is needed:\n\n- GenServer\n- Supervised processes\n- Processes started through other OTP abstractions","ref":"readme.html#event-context","title":"Event Context - Honeybadger for Elixir","type":"extras"},{"doc":"You can enable event sampling to reduce the number of events sent to\nHoneybadger. This is especially useful if you are hitting your daily event\nquota limit:\n\n```elixir\nconfig :honeybadger,\n  # Sample 50% of events\n  insights_sample_rate: 50\n```\n\nThe `insights_sample_rate` option accepts a whole percentage value between 0\nand 100, where 0 means no events will be sent and 100 means all events will be\nsent. The default is no sampling (100%).\n\nEvents are sampled by hashing the `request_id` if available in the event payload,\notherwise random sampling is used. This deterministic approach ensures that\nrelated events from the same request are consistently sampled together.\n\nThe sample rate is applied to all events sent to Honeybadger Insights, including\nautomatic instrumentation events. You can also set the sample rate per event\nby adding the `sample_rate` key to the event metadata map:\n\n```elixir\nHoneybadger.event(\"user_created\", %{\n  user_id: user.id,\n  _hb: %{sample_rate: 100}\n})\n```\n\nThe event sample rate can also be set within the `event_context/1` function.\nThis can be handy if you want to set an overall sample rate for a process or\nensure that specific instrumented events get sent:\n\n```elixir\n# Set a higher sampling rate for this entire process\nHoneybadger.event_context(%{_hb: %{sample_rate: 100}})\n\n# Now all events from this process, including automatic instrumentation,\n# will use the 100% sample rate\nEcto.Repo.insert!(%MyApp.User{}) # This instrumented event will be sent\n```\n\nRemember that context is process-bound and applies to all events sent from the\nsame process after the `event_context/1` call, until it's changed or the process\nterminates.\n\nWhen setting sample rates below the global setting, be aware that this affects\nhow events with the same `request_id` are sampled. Since sampling is\ndeterministic based on the `request_id` hash, all events sharing the same\n`request_id` will either all be sampled or all be skipped together. This\nensures consistency across related events.\n\nWith that in mind, it's recommended to default to the global sample rate and\nuse per-event sampling for specific cases where you want to ensure events are\nsent regardless of the global setting, or you are setting the sample rate in\nthe context where all events with the same `request_id` will also share the\nsame sampling rate.","ref":"readme.html#event-sampling","title":"Event Sampling - Honeybadger for Elixir","type":"extras"},{"doc":"Breadcrumbs allow you to record events along a processes execution path. If\nan error is thrown, the set of breadcrumb events will be sent along with the\nnotice. These breadcrumbs can contain useful hints while debugging.\n\nBreadcrumbs are stored in the logger context, referenced by the calling\nprocess. If you are sending messages between processes, breadcrumbs will not\ntransfer automatically. Since a typical system might have many processes, it\nis advised that you be conservative when storing breadcrumbs as each\nbreadcrumb consumes memory.","ref":"readme.html#breadcrumbs","title":"Breadcrumbs - Honeybadger for Elixir","type":"extras"},{"doc":"We leverage the `telemetry` library to automatically create breadcrumbs from\nspecific events.\n\n__Phoenix__\n\nIf you are using `phoenix` (>= v1.4.7) we add a breadcrumb from the router\nstart event.\n\n__Ecto__\n\nWe can create breadcrumbs from Ecto SQL calls if you are using `ecto_sql` (>=\nv3.1.0). You also must specify in the config which ecto adapters you want to\nbe instrumented:\n\n```elixir\nconfig :honeybadger,\n  ecto_repos: [MyApp.Repo]\n```","ref":"readme.html#automatic-breadcrumbs","title":"Automatic Breadcrumbs - Honeybadger for Elixir","type":"extras"},{"doc":"If you'd like to see the module in action before you integrate it with your apps, check out our [sample Phoenix application](https://github.com/honeybadger-io/crywolf-elixir).\n\nYou can deploy the sample app to your Heroku account by clicking this button:\n\n[![Deploy](https://www.herokucdn.com/deploy/button.png)](https://heroku.com/deploy?template=https://github.com/honeybadger-io/crywolf-elixir)\n\nDon't forget to destroy the Heroku app after you're done so that you aren't\ncharged for usage.\n\nThe code for the sample app is [available on Github](https://github.com/honeybadger-io/crywolf-elixir), in case you'd like to read through it, or run it locally.","ref":"readme.html#sample-application","title":"Sample Application - Honeybadger for Elixir","type":"extras"},{"doc":"Before data is sent to Honeybadger, it is passed through a filter to remove sensitive fields and do other processing on the data.  The default configuration is equivalent to:\n\n```elixir\nconfig :honeybadger,\n  filter: Honeybadger.Filter.Default,\n  filter_keys: [:password, :credit_card]\n```\n\nThis will remove any entries in the `context`, `session`, `cgi_data` and `params` that match one of the filter keys.  The filter is case insensitive and matches atoms or strings.\n\nIf `Honeybadger.Filter.Default` does not suit your needs, you can implement your own filter. See the `Honeybadger.Filter.Mixin` module doc for details on implementing your own filter.","ref":"readme.html#filtering-sensitive-data","title":"Filtering Sensitive Data - Honeybadger for Elixir","type":"extras"},{"doc":"Honeybadger can show arguments in the stacktrace for `FunctionClauseError` exceptions. To enable argument reporting, set `filter_args` to `false`:\n\n```elixir\nconfig :honeybadger, filter_args: false\n```","ref":"readme.html#filtering-arguments","title":"Filtering Arguments - Honeybadger for Elixir","type":"extras"},{"doc":"By default Honeybadger will be notified when an error occurs. To override this configuration in order not to send out errors to Honeybadger, set `exclude_errors` option in `config/config.exs`.\n\nThis can be done by passing a list of errors to be excluded:\n\n```elixir\nconfig :honeybadger,\n  exclude_errors: [\"RuntimeError\"]\n```\n\nor\n\n```elixir\nconfig :honeybadger,\n  exclude_errors: [RuntimeError]\n```\nAlso you can implement the `Honeybadger.ExcludeErrors` behaviour function `exclude_error?/1`, which receives the full `Honeybadger.Notice` and returns a boolean signalling the error exclusion or not.\n\n```elixir\n\n  defmodule ExcludeFunClauseErrors do\n    alias Honeybadger.ExcludeErrors\n\n    @behaviour ExcludeErrors\n\n    @impl ExcludeErrors\n\n    def exclude_error?(notice) do\n      notice.error.class == \"FunctionClauseError\"\n    end\n  end\n\n```\n\n```elixir\nconfig :honeybadger,\n  exclude_errors: ExcludeFunClauseErrors\n```","ref":"readme.html#excluding-errors","title":"Excluding Errors - Honeybadger for Elixir","type":"extras"},{"doc":"See the [Error Monitoring Guide](https://docs.honeybadger.io/guides/errors/#error-grouping) for more information about how honeybadger groups similar exception together. You can customize the grouping for each exception in Elixir by sending a custom *fingerprint* when the exception is reported.\n\nTo customize the fingerprint for all exceptions that are reported from your app, use the `fingerprint_adapter` configuration option in `config.ex`:\n\n```elixir\nconfig :honeybadger, fingerprint_adapter: MyApp.CustomFingerprint\n```\n\n```elixir\n defmodule MyApp.CustomFingerprint do\n  @behaviour Honeybadger.FingerprintAdapter\n\n  def parse(notice) do\n    notice.notifier.language <> \"-\" <> notice.notifier.name\n  end\nend\n```\n\nYou can also customize the fingerprint for individual exceptions when calling `Honeybadger.notify`:\n\n```elixir\nHoneybadger.notify(%RuntimeError{}, fingerprint: \"culprit_id-123\")\n```","ref":"readme.html#customizing-error-grouping","title":"Customizing Error Grouping - Honeybadger for Elixir","type":"extras"},{"doc":"You can set configuration options in `config.exs`. It looks like this:\n\n```elixir\nconfig :honeybadger,\n  api_key: \"{{PROJECT_API_KEY}}\",\n  environment_name: :prod\n```\n\nIf you'd rather read, eg., `environment_name` from the OS environment, you can do like this:\n\n```elixir\nconfig :honeybadger,\n  environment_name: {:system, \"HONEYBADGER_ENV\"},\n  revision: {:system, \"HEROKU_SLUG_COMMIT\"}\n```\n\n_NOTE: This works only for the string options, and `environment_name`._\n\nHere are all of the options you can pass in the keyword list:\n\n| Name                      | Description                                                                                   | Default                                  |\n| ------------------------- | --------------------------------------------------------------------------------------------- | ---------------------------------------- |\n| `app`                     | Name of your app's OTP Application as an atom                                                 | `Mix.Project.config[:app]`               |\n| `api_key`                 | Your application's Honeybadger API key                                                        | `System.get_env(\"HONEYBADGER_API_KEY\"))` |\n| `environment_name`        | (required) The name of the environment your app is running in.                                | `:prod`                                  |\n| `exclude_errors`          | Filters out errors from being sent to Honeybadger                                             | `[]`                                     |\n| `exclude_envs`            | Environments that you want to disable Honeybadger notifications                               | `[:dev, :test]`                          |\n| `hostname`                | Hostname of the system your application is running on                                         | `:inet.gethostname`                      |\n| `origin`                  | URL for the Honeybadger API                                                                   | `\"https://api.honeybadger.io\"`           |\n| `project_root`            | Directory root for where your application is running                                          | `System.cwd/0`                           |\n| `revision`                | The project's git revision                                                                    | `nil`                                    |\n| `filter`                  | Module implementing `Honeybadger.Filter` to filter data before sending to Honeybadger.io      | `Honeybadger.Filter.Default`             |\n| `filter_keys`             | A list of keywords (atoms) to filter.  Only valid if `filter` is `Honeybadger.Filter.Default` | `[:password, :credit_card, :__changed__, :flash, :_csrf_token]` |\n| `filter_args`             | If true, will remove function arguments in backtraces                                         | `true`                                   |\n| `filter_disable_url`      | If true, will remove the request url                                                          | `false`                                  |\n| `filter_disable_session`  | If true, will remove the request session                                                      | `false`                                  |\n| `filter_disable_params`   | If true, will remove the request params                                                       | `false`                                  |\n| `filter_disable_assigns`  | If true, will remove the live_view event assigns                                              | `false`                                  |\n| `fingerprint_adapter`     | Implementation of FingerprintAdapter behaviour                                                |                                          |\n| `notice_filter`           | Module implementing `Honeybadger.NoticeFilter`. If `nil`, no filtering is done.               | `Honeybadger.NoticeFilter.Default`       |\n| `sasl_logging_only`       | If true, will notifiy for SASL errors but not Logger calls                                    | `true`                                   |\n| `use_logger`              | Enable the Honeybadger Logger for handling errors outside of web requests                     | `true`                                   |\n| `ignored_domains`         | Add domains to ignore Error events in `Honeybadger.Logger`.                                   | `[:cowboy]`                              |\n| `breadcrumbs_enabled`     | Enable breadcrumb event tracking                                                              | `false`                                  |\n| `ecto_repos`              | Modules with implemented Ecto.Repo behaviour for tracking SQL breadcrumb events               | `[]`                                     |\n| `event_filter`            | Module implementing `Honeybadger.EventFilter`. If `nil`, no filtering is done.                | `Honeybadger.EventFilter.Default`        |\n| `insights_enabled`        | Enable sending automatic events to Honeybadger Insights                                       | `false`                                  |\n| `insights_config`         | Specific library Configuration for Honeybadger Insights.                                      | `%{}`                                    |\n| `http_adapter`            | Module implementing `Honeybadger.HttpAdapter` to send data to Honeybadger.io                  | Any available adapter (`Req`, `hackney`) |\n| `events_worker_enabled`   | Enable sending events in a separate process                                                   | `true`                                   |\n| `events_max_batch_retries`| Maximum number of retries for sending events                                                  | `3`                                      |\n| `events_batch_size`       | Maximum number of events to send in a single batch                                            | `1000`                                   |\n| `events_max_queue_size`   | Maximum number of events to queue before dropping                                             | `10000`                                  |\n| `events_timeout`          | Timeout in milliseconds for sending events                                                    | `5000`                                   |\n| `events_throttle_wait`    | Time in milliseconds to wait before retrying a failed batch                                   | `60000`                                  |","ref":"readme.html#advanced-configuration","title":"Advanced Configuration - Honeybadger for Elixir","type":"extras"},{"doc":"The HTTP client used to send data to Honeybadger can be customized. We will use\neither `Req` or `hackney` (in that order) by default if they are loaded. If you\nwant to use a different HTTP client, you can set the `http_adapter` configuration\noption to any of our pre-built adapter modules.\n\n```elixir\nconfig :honeybadger,\n  # Without options\n  http_adapter: Honeybadger.HTTPAdapter.Hackney\n  # With options\n  http_adapter: {Honeybadger.HTTPAdapter.Hackney, [...]}\n```\n\nYou can also implement your own HTTP adapter to send data to Honeybadger. The\nadapter must implement the `Honeybadger.HttpAdapter` behaviour.","ref":"readme.html#http-adapters","title":"HTTP Adapters - Honeybadger for Elixir","type":"extras"},{"doc":"### `Honeybadger.notify`: Send an exception to Honeybadger.\n\nUse the `Honeybadger.notify/2` function to send exception information to the\ncollector API.  The first parameter is the exception and the second parameter\nis the context/metadata/fingerprint. There is also a `Honeybadger.notify/1` which doesn't require the second parameter.\n\n#### Examples:\n\n```elixir\ntry do\n  File.read! \"this_file_really_should_exist_dang_it.txt\"\nrescue\n  exception ->\n    context = %{user_id: 5, account_name: \"Foo\"}\n    Honeybadger.notify(exception, metadata: context, stacktrace: __STACKTRACE__)\nend\n```\n\n---\n\n\n### `Honeybadger.context/1`: Set metadata to be sent if an error occurs\n\n`Honeybadger.context/1` is provided for adding extra data to the notification\nthat gets sent to Honeybadger. You can make use of this in places such as a Plug\nin your Phoenix Router or Controller to ensure useful debugging data is sent along.\n\n#### Examples:\n\n```elixir\ndef MyPhoenixApp.Controller\n  use MyPhoenixApp.Web, :controller\n\n  plug :set_honeybadger_context\n\n  def set_honeybadger_context(conn, _opts) do\n    user = get_user(conn)\n    Honeybadger.context(user_id: user.id, account: user.account.name)\n    conn\n  end\nend\n```\n\n`Honeybadger.context/1` stores the context data in the process dictionary, so\nit will be sent with errors/notifications on the same process. The following\n`Honeybadger.notify/1` call will not see the context data set in the previous line.\n\n```elixir\nHoneybadger.context(user_id: 5)\nTask.start(fn ->\n  # this notify does not see the context set earlier\n  # as this runs in a different elixir/erlang process.\n  Honeybadger.notify(%RuntimeError{message: \"critical error\"})\nend)\n```\n\n---\n\n### `Honeybadger.add_breadcrumb/2`: Store breadcrumb within process\n\nAppends a breadcrumb to the notice. Use this when you want to add some custom\ndata to your breadcrumb trace in effort to help debugging. If a notice is\nreported to Honeybadger, all breadcrumbs within the execution path will be\nappended to the notice. You will be able to view the breadcrumb trace in the\nHoneybadger interface to see what events led up to the notice.\n\n#### Examples:\n\n```elixir\nHoneybadger.add_breadcrumb(\"Email sent\", metadata: %{\n  user: user.id,\n  message: message\n})\n```\n\n---\n\n### `Honeybadger.event`: Send an event to Honeybadger Insights.\n\nUse the `Honeybadger.event/1` function to send event data to the events API. A\n`ts` field with the current timestamp will be added to the data if it isn't\nprovided. You can also use `Honeybadger.event/2`, which accepts a string as the\nfirst parameter and adds that value to the `event_type` field in the map before\nbeing sent to the API.\n\n#### Examples:\n\n```elixir\nHoneybadger.event(%{\n  event_type: \"user_created\",\n  user: user.id\n})\n\nHoneybadger.event(\"project_deleted\", %{\n  project: project.name\n})\n```\n\n---","ref":"readme.html#public-interface","title":"Public Interface - Honeybadger for Elixir","type":"extras"},{"doc":"If your server needs a proxy to access Honeybadger, add the following to your config\n\n```elixir\nconfig :honeybadger,\n  proxy: \"url\",\n  proxy_auth: {\"username\", \"password\"}\n```","ref":"readme.html#proxy-configuration","title":"Proxy configuration - Honeybadger for Elixir","type":"extras"},{"doc":"Honeybadger won't report errors from `:dev` and `:test` environments by default. To enable error reporting in dev:\n\n1. Set the HONEYBADGER_API_KEY as documented above\n2. Remove `:dev` from the `exclude_envs` by adding this to your config/dev.exs\n```elixir\nconfig :honeybadger,\n  exclude_envs: [:test]\n```\n3. Run the `mix honeybadger.test` mix task task to simulate an error","ref":"readme.html#excluded-environments","title":"Excluded environments - Honeybadger for Elixir","type":"extras"},{"doc":"See https://github.com/honeybadger-io/honeybadger-elixir/blob/master/CHANGELOG.md","ref":"readme.html#changelog","title":"Changelog - Honeybadger for Elixir","type":"extras"},{"doc":"If you're adding a new feature, please [submit an\nissue](https://github.com/honeybadger-io/honeybadger-elixir/issues/new) as a\npreliminary step; that way you can be (moderately) sure that your pull request\nwill be accepted.","ref":"readme.html#contributing","title":"Contributing - Honeybadger for Elixir","type":"extras"},{"doc":"1. Fork it.\n2. Create a topic branch `git checkout -b my_branch`\n3. Commit your changes `git commit -am \"Boom\"`\n4. Push to your branch `git push origin my_branch`\n5. Send a [pull request](https://github.com/honeybadger-io/honeybadger-elixir/pulls)","ref":"readme.html#to-contribute-your-code","title":"To contribute your code: - Honeybadger for Elixir","type":"extras"},{"doc":"#### Github Workflow\n\nA new version can be published on Hex.pm using the Publish New Release workflow.\nThe workflow can be triggered manually from the Github Actions page and takes the following input:\n- `version`: One of `patch`, `minor` or `major`. The version number will be bumped accordingly.\n- `changes`: An entry to be added to the changelog.\n\n#### Manual Release\n\nVersioning, changelog generation and publishing to hex.pm is handled by the `mix expublish` task.\nYou can read more about it [here](https://github.com/ucwaldo/expublish).\n\n1. `mix deps.get`\n2. echo \"CHANGELOG ENTRY\" > RELEASE.MD\n3. `mix expublish.[patch|minor|major]`","ref":"readme.html#publishing-a-release-on-hex-pm","title":"Publishing a release on hex.pm - Honeybadger for Elixir","type":"extras"},{"doc":"This library is MIT licensed. See the\n[LICENSE](https://raw.github.com/honeybadger-io/honeybadger-elixir/master/LICENSE)\nfile in this repository for details.","ref":"readme.html#license","title":"License - Honeybadger for Elixir","type":"extras"},{"doc":"# Changelog\n\nAll notable changes to this project will be documented in this file. See [Keep a\nCHANGELOG](http://keepachangelog.com/) for how to update this file. This project\nadheres to [Semantic Versioning](http://semver.org/).\n\n<!-- %% CHANGELOG_ENTRIES %% -->","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Bug fix for OTP 28: Move regex constants to functions (#635)","ref":"changelog.html#0-24-1-2025-07-02","title":"0.24.1 - 2025-07-02 - Changelog","type":"extras"},{"doc":"This release focuses on comprehensive Insights instrumentation enhancements, featuring automatic instrumentation for the most popular libraries, event batching, configurable sampling rates, and event context tracking for improved performance monitoring.","ref":"changelog.html#0-24-0-2025-04-28","title":"0.24.0 - 2025-04-28 - Changelog","type":"extras"},{"doc":"- Added Insights instrumentation for detailed monitoring (#591)\n- Added Insights event batching for optimized performance (#578)\n- Added event sampling capabilities with configurable sample rates (#613, #608)\n- Added `Honeybadger.EventContext` for enhanced context tracking (#606)\n- Added `event_filter/1` function for custom event filtering (#602)\n- Added Request ID to Insights events and notices (#597)\n- Added support for Ecto params with source whitelisting (#605)","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Revised event logging system for better performance (#609)\n- Upgraded to microsecond precision for measurements (#603)\n- Enhanced sanitizer functionality (#604)","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"Added support for multiple HTTP client libraries (thanks @fastjames!)","ref":"changelog.html#0-23-0-2025-03-18","title":"0.23.0 - 2025-03-18 - Changelog","type":"extras"},{"doc":"Bugfix for Elixir 1.17","ref":"changelog.html#0-22-1-2024-12-19","title":"0.22.1 - 2024-12-19 - Changelog","type":"extras"},{"doc":"","ref":"changelog.html#0-22-0-2024-08-29","title":"0.22.0 - 2024-08-29 - Changelog","type":"extras"},{"doc":"- Add Honeybadger.event to send events to Insights","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"switched from Logger.warn to Logger.warning","ref":"changelog.html#0-21-0-2023-11-02","title":"0.21.0 - 2023-11-02 - Changelog","type":"extras"},{"doc":"- stop using logger metadata for breadcrumbs\n- publish using github actions\n\n\n## [v0.19.0] - 2022-10-27","ref":"changelog.html#0-20-0-2023-05-05","title":"0.20.0 - 2023-05-05 - Changelog","type":"extras"},{"doc":"- Add config option `exclude_errors` that excludes errors from being sent to the Honeybadger servers.(#443)\n\n## [v0.18.1] - 2021-11-16","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Avoid local function captures in Telemetry.attrach_many/4 (#400)\n\n## [v0.18.0] - 2021-09-28","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Update the minimum Elixir version to 1.10 (#390). Phoenix v1.5.11 causes a compilation error due to the new `mime` dependency, which requires Elixir 1.10+.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Support latest telemetry dependency. (#397)\n\n##### NB: Due to the upgrade of phoenix from v1.5.10 to v1.5.11 you must be on Elixir 1.10+\n\n## [v0.17.0] - 2021-08-16","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- fix callback spec arg type mismatch for handle_errors/2 from plugs (#384)","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Default `filter_args` to `false` (#375)","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Make notification for `Logger.error` configurable (#380, @yukster)\n\n## [v0.16.4] - 2021-07-13","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Show arguments in stacktrace for `FunctionClauseError` when `filter_args = false` (#123, #373)\n\n## [v0.16.3] - 2021-07-05","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Handle `extra_info` with `error_info` in `Honeybadger.Backtrace.format_line` (#369, @abstractcoder)\n- Prevent infinite loop with `use_logger: true` when logging internal errors (#370)\n\n## [v0.16.2] - 2021-04-27","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Encode notice message iodata before json serialize (#361)\n\n## [v0.16.1] - 2021-04-12","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Call custom `filter_cgi_data/1` in `NoticeFilter` (#353)\n\n## [v0.16.0] - 2021-02-22","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Send notifications on error-level logs\n- Added `ignored_domain` config with `[:cowboy]` as default\n\n## [v0.15.0] - 2020-09-24","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- New fingerprint option and config for `Honeybadger.notify/2`. Thanks @brunozrk! (#305)\n\n## [v0.14.1] - 2020-07-06","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Implement Jason.Encoder for RingBuffer (#294)\n\n## [v0.14.0] - 2020-03-12","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Breadcrumbs on by default\n\n## [v0.13.1] - 2020-02-06","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Safely sanitize invalid binaries when encoding JSON for notices.\n- Fixes for Elixir 1.10 release (#259)\n\n## [v0.13.0] - 2019-10-02","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Introducing Breadcrumbs (#235)! After enabling in the config with\n  `breadcrumbs_enabled: true`, just call `Honeybadger.add_breadcrumb/2`\n  anywhere in your code and if an error is reported in that process, the\n  breadcrumb event will be passed along with the Notice.","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Renamed Notifier to `honeybadger-elixir` and added language\n\n## [v0.12.1] - 2019-06-12","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Call `Exception.blame/3` after normalizing string errors, which prevents\n  reporint all string messages as Erlang errors. (#225)\n\n## [v0.12.0] - 2019-05-30","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Added `:revision` configuration option\n- Automatically call `Exception.blame/3` to record additional information in the exception\n\n## [v0.11.0] - 2019-02-28\nWhen upgrading to v0.11, users should be aware of a few important changes:\n\n- You must be on Elixir 1.7+ and Erlang/OTP 21+\n- Due to the deprecation of `System.stacktrace/0` and the introduction of [`__STACKTRACE__`](https://hexdocs.pm/elixir/Kernel.SpecialForms.html#__STACKTRACE__/0), manually calling `Honeybadger.notify/3` will no longer include a stacktrace by default. See the [issue discussion](https://github.com/honeybadger-io/honeybadger-elixir/pull/204) for more details\n- A stacktrace can be manually provided from within a rescue/catch block via the __STACKTRACE__ macro, e.g. `Honeybadger.notify(SomeError, %{my: :context}, __STACKTRACE__)`","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Switch from Erlang's `:error_logger` to an Elixir 1.7 and Erlang/OTP 21+\n  `Logger` backend. This provides more consistent error reporting and enhanced\n  integration with Logger metadata.\n- Stop automatically extracting stacktraces for calls to `Honeybadger.notice/3`.\n  The generated stacktrace was unreliably and frequently listed the Honeybadger\n  reporter's internals, rather than application code. Manual calls to `notice/3`\n  should happen within a `rescue/catch` block and use the `__STACKTRACE__`\n  macro.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Use `Logger.metadata` as the basis for Honeybadger context in all logger\n  generated notices","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Fix Map.t() isn't a valid dialyzer type (#198)\n- Try to convert remote IP to string in case of parsing failure\n\n## [v0.10.3] - 2018-07-02","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Prevent crashes reporting `:badmatch` when fetching the current stacktrace\n  from a dead process.\n- Updated dependencies.\n\n## [v0.10.2] - 2018-07-02","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Fix crashes caused by presence of structs in the context.\n\n## [v0.10.1] - 2018-06-27","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Handle fetching peer info when using Plug 1.6. This is implemented in a\n  backward compatible manner, so versions < 1.6 will continue to work.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Fetch peer information for multiple plug versions\n- Bump phoenix from 1.3.2 to 1.3.3\n- Bump hackney from 1.12.1 to 1.13.0\n\n## [v0.10.0] - 2018-05-29","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Replace Poison with Jason for JSON encoding.\n- Reduce the log level used for dev mode warning.\n- Update dependenices.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"JSON encoding error.\n- Send notifications even when the stacktrace isn't a list. Errors reported from\n  the error logger can occasionally have a malformed stacktrace, which would\n  raise another exception and prevent the notification from being sent.\n\n## [v0.9.0] - 2018-03-21","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Use lazy logging within `Honeybadger.Client`, this allows compile time purging\n  when the log level is set higher.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Fix a regression which was causing `Not Found (404)` errors to be reported.\n- Fix an issue caused by hackney because of unread response bodies.\n\n## [v0.8.0] - 2018-01-17","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Include function arity in notice backtraces. For example, the reported method\n  would be `notify/3` instead of `notify`.\n- Include function arguments in notice backtraces. This is disabled by default,\n  and can be enabled by setting `filter_args` to `false` in configuration.","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Allow `handle_errors` from `Honeybadger.Plug` to be overridden.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Safely convert binary `:environment_name` values to an atom. If the\n  environment was specified via `{:system, \"HONEYBADGER_ENV\"}` and the\n  `HONEYBADGER_ENV` value didn't already exist as an atom the app would fail to\n  boot.\n- Ignore the absence of `HONEYBADGER_API_KEY` when running in an excluded env\n\n\n## [v0.7.0] - 2017-11-07","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Increases the logging around client activity\n  (honeybadger-io/honeybadger-elixir#20).\n- Explicitly allow sending notices with strings and maps. For example, it is now\n  possible to send a `RuntimeError` by calling `Honeybadger.notify(\"oops!\")`.\n- Added Honeybadger test mix task which can be invoked using `mix honeybadger.test`","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Switch from `GenEvent` to implementing `gen_event` behaviour.\n- Remove `error_logger` backend on application stop.\n- Use the latest exception's stacktrace whenever `notify` is called from a\n  `try` expression.\n- Namespace modules related to `Filter` and `NoticeFilter`. This is largely an\n  internal restructuring, but any custom filters that used the\n  `Honeybadger.FilterMixin` will need to specify `Honeybadger.Filter.Mixin`\n  instead.\n- Drops `HTTPoison` in favor of directly using `Hackney`, which gives us access to\n  a connection pool.\n- Drops Meck and stubbing in favor of a local cowboy server\n  (honeybadger-io/honeybadger-elixir#7).\n- Starts a supervision tree with the client as a child.\n- Report the controller and action name as component and action for phoenix apps","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Filtering CGI data now respects the `filter_disable_url` setting. All path\n  related fields (`ORIGINAL_FULLPATH`, `QUERY_STRING`, `PATH_INFO`) are filtered\n  now.\n- Get the environment directly from `Mix.env` and always compare the environment\n  names as atoms (honeybadger-io/honeybadger-elixir#94).\n- Changes notify from a macro to a function.\n- Stops spawning new tasks for every error, instead relying on async handling in\n  the client (honeybadger-io/honeybadger-elixir#88).\n\n## [0.6.3] - 2017-05-04","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Removes metrics reporting.","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Loosens httpoison dependency.\n- Misc. bug fixes.\n\n## [0.6.2] - 2016-10-24","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- ability to customize error names/messages,","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- stops plug error notifications from being sent twice\n- minor typo fixes\n- dependency updates\n\n## [0.6.1] - 2016-08-02","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Reformatting the plug environment data sent to Honeybadger.\n\n## [0.6.0] - 2016-07-22","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- This release removes warnings for Elixir 1.3.0 and covers v1.4.0-dev as of\n  2016-07-22. There was also a switch to using `:native` `FromUnits` to match\n  the `Plug.Logger` usage of `:erlang.convert_time_unit`. This maintains\n  consistency between `Honeybadger.Logger` and `Plug.Logger`.\n\n## [0.5.0] - 2016-04-26","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"- Honeybadger now collects successful response times, aggregates them and sends\n  them to the Honeybadger API! You can see request metric data from the metrics\n  tab on Honeybadger.io!\n\n## [0.4.0] - 2016-02-23","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"- Due to the `Mix.env/0` function always being set to `prod` for dependencies and\n  Mix being compiled out of applications by exrm, we now require you to\n  explicitly declare your `environment_name` for every environment in your\n  `config.exs` files.\n\n      Example:\n        # config/dev.exs\n        config :honeybadger, environment_name: :dev\n\n  Doing this will ensure you get accurate environment information for exceptions\n  that happen at runtime as well as compile time. You can also set the\n  `environment_name` setting a `MIX_ENV` environment variable.\n\n      Example:\n      $ MIX_ENV=prod mix phoenix.server\n\n  **Note:** setting `environment_name` in your config files takes higher\n  precedence than the `MIX_ENV` environment variable.\n\n## [0.3.1] - 2016-02-04","ref":"changelog.html#changed","title":"Changed - Changelog","type":"extras"},{"doc":"- Fix a bug where notifications reported by the `error_logger` were not\n  sending the the context","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"}],"producer":{"name":"ex_doc","version":"0.37.1"},"proglang":"elixir"}